==> declarativex-1.4.0.tar.gz: declarativex-1.4.0/README.md <==
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/declarativex?style=for-the-badge&logo=python&logoColor=FF0077&color=FFD43B)](https://pypi.org/project/declarativex)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/declarativex?style=for-the-badge&link=https%3A%2F%2Fpypi.org%2Fproject%2Fdeclarativex&color=FFD43B&logoColor=FF0077&logo=ownCloud)](https://pypi.org/project/declarativex)
[![PyPI - Version](https://img.shields.io/pypi/v/declarativex?style=for-the-badge&logo=pypi&color=FFD43B&logoColor=FF0077)](https://pypi.org/project/declarativex)
[![Coverage](https://img.shields.io/badge/COVERAGE-100%25-FFD43B?style=for-the-badge&logo=codecov)](https://pypi.org/project/declarativex)


# DeclarativeX - Declarative HTTP Client

## Why DeclarativeX? 🤔

Tired of spelling out each HTTP step? Headers, JSON parsing, the whole shebang? Chill, `DeclarativeX` is here to
simplify your life. Now you can focus on what actually matters — your business logic.

## Key Features 🗝️

- **Declarative Syntax**: Just slap on some decorators, and you're good to go.
- **Function-based Declaration**: Don't want to create a class? No problem, check the docs.
- **Data Validation**: Got Pydantic? We've got your back on robust data validation.
- **Async Support**: Async you said? Yep, we're all in.
- **Rate limiting**: Don't want to get banned? We've got you covered.
- **Middlewares**: Need to add some custom logic? Specify your custom dependency.
- **Automatic body parsing**: Don't want to parse the response manually? Provide a dataclass or Pydantic model as return type.

## How to Get It 🛠

```bash
pip install declarativex
```

## Documentation 📚

Documentation is available at [https://floydya.github.io/declarativex](https://floydya.github.io/declarativex).

## Support the Creator 🙌

If you're digging DeclarativeX and want to give back, consider supporting the creator. Your contributions help keep this
project alive and kicking!

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/E1E2OL196)

Every bit helps and is massively appreciated! 🌟

==> declarativex-1.4.1.tar.gz: declarativex-1.4.1/README.md <==
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/declarativex?style=for-the-badge&logo=python&logoColor=FF0077&color=FFD43B)](https://pypi.org/project/declarativex)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/declarativex?style=for-the-badge&link=https%3A%2F%2Fpypi.org%2Fproject%2Fdeclarativex&color=FFD43B&logoColor=FF0077&logo=ownCloud)](https://pypi.org/project/declarativex)
[![PyPI - Version](https://img.shields.io/pypi/v/declarativex?style=for-the-badge&logo=pypi&color=FFD43B&logoColor=FF0077)](https://pypi.org/project/declarativex)
[![Coverage](https://img.shields.io/badge/COVERAGE-100%25-FFD43B?style=for-the-badge&logo=codecov)](https://pypi.org/project/declarativex)


# DeclarativeX - Declarative HTTP Client

## Why DeclarativeX? 🤔

Tired of spelling out each HTTP step? Headers, JSON parsing, the whole shebang? Chill, `DeclarativeX` is here to
simplify your life. Now you can focus on what actually matters — your business logic.

## Key Features 🗝️

- **Declarative Syntax**: Just slap on some decorators, and you're good to go.
- **Function-based Declaration**: Don't want to create a class? No problem, check the docs.
- **Data Validation**: Got Pydantic? We've got your back on robust data validation.
- **Async Support**: Async you said? Yep, we're all in.
- **Rate limiting**: Don't want to get banned? We've got you covered.
- **Middlewares**: Need to add some custom logic? Specify your custom middleware.
- **Automatic body parsing**: Don't want to parse the response manually? Provide a dataclass or Pydantic model as return type.

## How to Get It 🛠

```bash
pip install declarativex
```

## Documentation 📚

Documentation is available at [https://floydya.github.io/declarativex](https://floydya.github.io/declarativex).

## Support the Creator 🙌

If you're digging DeclarativeX and want to give back, consider supporting the creator. Your contributions help keep this
project alive and kicking!

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/E1E2OL196)

Every bit helps and is massively appreciated! 🌟
